kombu.entity — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# kombu.entity

Exchange and Queue declarations.

copyright: | 2009 - 2011 by Ask Solem.
license: | BSD, see LICENSE for more details.

- Exchange
- Queue

## Exchange

Example creating an exchange declaration:

    >>> news_exchange = Exchange("news", type="topic")

For now news_exchange is just a declaration, you can’t perform actions on it. It just describes the name and options for the exchange.

The exchange can be bound or unbound. Bound means the exchange is associated with a channel and operations can be performed on it. To bind the exchange you call the exchange with the channel as argument:

    >>> bound_exchange = news_exchange(channel)

Now you can perform operations like `declare()` or `delete()`:

    >>> bound_exchange.declare()
    >>> message = bound_exchange.Message("Cure for cancer found!")
    >>> bound_exchange.publish(message, routing_key="news.science")
    >>> bound_exchange.delete()

class `kombu.entity.` `Exchange`(name='', type='', channel=None, **kwargs)

  An Exchange declaration.

  Parameters: | name – See `name`. type – See `type`. channel – See `channel`. durable – See `durable`. auto_delete – See `auto_delete`. delivery_mode – See `delivery_mode`. arguments – See `arguments`.

  `name`

    Name of the exchange. Default is no name (the default exchange).

  `type`

    AMQP defines four default exchange types (routing algorithms) that covers most of the common messaging use cases. An AMQP broker can also define additional exchange types, so see your broker manual for more information about available exchange types.

    > - direct (default)

    >   > Direct match between the routing key in the message, and the routing criteria used when a queue is bound to this exchange.

    > - topic

    >   > Wildcard match between the routing key and the routing pattern specified in the exchange/queue binding. The routing key is treated as zero or more words delimited by ”.” and supports special wildcard characters. “*” matches a single word and “#” matches zero or more words.

    > - fanout

    >   > Queues are bound to this exchange with no arguments. Hence any message sent to this exchange will be forwarded to all queues bound to this exchange.

    > - headers

    >   > Queues are bound to this exchange with a table of arguments containing headers and values (optional). A special argument named “x-match” determines the matching algorithm, where “all” implies an AND (all pairs must match) and “any” implies OR (at least one pair must match).

    >   > `arguments` is used to specify the arguments.

    > This description of AMQP exchange types was shamelessly stolen from the blog post AMQP in 10 minutes: Part 4 by Rajith Attapattu. This article is recommended reading.

  `channel`

    The channel the exchange is bound to (if bound).

  `durable`

    Durable exchanges remain active when a server restarts. Non-durable exchanges (transient exchanges) are purged when a server restarts. Default is `True`.

  `auto_delete`

    If set, the exchange is deleted when all queues have finished using it. Default is `False`.

  `delivery_mode`

    The default delivery mode used for messages. The value is an integer, or alias string.

    > - 1 or “transient”

    >   > The message is transient. Which means it is stored in memory only, and is lost if the server dies or restarts.

    > - 2 or “persistent” (default)

    >     The message is persistent. Which means the message is stored both in-memory, and on disk, and therefore preserved if the server dies or restarts.

    The default value is 2 (persistent).

  `arguments`

    Additional arguments to specify when the exchange is declared.

  `maybe_bind`(channel)

    Bind instance to channel if not already bound.

  `Message`(body, delivery_mode=None, priority=None, content_type=None, content_encoding=None, properties=None, headers=None)

    Create message instance to be sent with `publish()`.

    Parameters: | body – Message body. delivery_mode – Set custom delivery mode. Defaults to `delivery_mode`. priority – Message priority, 0 to 9. (currently not supported by RabbitMQ). content_type – The messages content_type. If content_type is set, no serialization occurs as it is assumed this is either a binary object, or you’ve done your own serialization. Leave blank if using built-in serialization as our library properly sets content_type. content_encoding – The character set in which this object is encoded. Use “binary” if sending in raw binary objects. Leave blank if using built-in serialization as our library properly sets content_encoding. properties – Message properties. headers – Message headers.

  `declare`(nowait=False)

    Declare the exchange.

    Creates the exchange on the broker.

    Parameters: | nowait – If set the server will not respond, and a response will not be waited for. Default is `False`.

  `delete`(if_unused=False, nowait=False)

    Delete the exchange declaration on server.

    Parameters: | if_unused – Delete only if the exchange has no bindings. Default is `False`. nowait – If set the server will not respond, and a response will not be waited for. Default is `False`.

  `publish`(message, routing_key=None, mandatory=False, immediate=False, exchange=None)

    Publish message.

    Parameters: | message – `Message()` instance to publish. routing_key – Routing key. mandatory – Currently not supported. immediate – Currently not supported.

## Queue

Example creating a queue using our exchange in the `Exchange` example:

    >>> science_news = Queue("science_news",
    ...                      exchange=news_exchange,
    ...                      routing_key="news.science")

For now science_news is just a declaration, you can’t perform actions on it. It just describes the name and options for the queue.

The queue can be bound or unbound. Bound means the queue is associated with a channel and operations can be performed on it. To bind the queue you call the queue instance with the channel as an argument:

    >>> bound_science_news = science_news(channel)

Now you can perform operations like `declare()` or `purge()`:

    >>> bound_sicence_news.declare()
    >>> bound_science_news.purge()
    >>> bound_science_news.delete()

class `kombu.entity.` `Queue`(name='', exchange=None, routing_key='', channel=None, **kwargs)

  A Queue declaration.

  Parameters: | name – See `name`. exchange – See `exchange`. routing_key – See `routing_key`. channel – See `channel`. durable – See `durable`. exclusive – See `exclusive`. auto_delete – See `auto_delete`. queue_arguments – See `queue_arguments`. binding_arguments – See `binding_arguments`.

  `name`

    Name of the queue. Default is no name (default queue destination).

  `exchange`

    The `Exchange` the queue binds to.

  `routing_key`

    The routing key (if any), also called binding key.

    The interpretation of the routing key depends on the `Exchange.type`.

    > - direct exchange

    >   > Matches if the routing key property of the message and the `routing_key` attribute are identical.

    > - fanout exchange

    >   > Always matches, even if the binding does not have a key.

    > - topic exchange

    >   > Matches the routing key property of the message by a primitive pattern matching scheme. The message routing key then consists of words separated by dots (”.”, like domain names), and two special characters are available; star (“*”) and hash (“#”). The star matches any word, and the hash matches zero or more words. For example “*.stock.#” matches the routing keys “usd.stock” and “eur.stock.db” but not “stock.nasdaq”.

  `channel`

    The channel the Queue is bound to (if bound).

  `durable`

    Durable queues remain active when a server restarts. Non-durable queues (transient queues) are purged if/when a server restarts. Note that durable queues do not necessarily hold persistent messages, although it does not make sense to send persistent messages to a transient queue.

    Default is `True`.

  `exclusive`

    Exclusive queues may only be consumed from by the current connection. Setting the ‘exclusive’ flag always implies ‘auto-delete’.

    Default is `False`.

  `auto_delete`

    If set, the queue is deleted when all consumers have finished using it. Last consumer can be cancelled either explicitly or because its channel is closed. If there was no consumer ever on the queue, it won’t be deleted.

  `queue_arguments`

    Additional arguments used when declaring the queue.

  `binding_arguments`

    Additional arguments used when binding the queue.

  `maybe_bind`(channel)

    Bind instance to channel if not already bound.

  `cancel`(consumer_tag)

    Cancel a consumer by consumer tag.

  `consume`(consumer_tag='', callback=None, no_ack=None, nowait=False)

    Start a queue consumer.

    Consumers last as long as the channel they were created on, or until the client cancels them.

    Parameters: | consumer_tag – Unique identifier for the consumer. The consumer tag is local to a connection, so two clients can use the same consumer tags. If this field is empty the server will generate a unique tag. no_ack – If set messages received does not have to be acknowledged. nowait – Do not wait for a reply. callback – callback called for each delivered message

  `declare`(nowait=False)

    Declares the queue, the exchange and binds the queue to the exchange.

  `delete`(if_unused=False, if_empty=False, nowait=False)

    Delete the queue.

    Parameters: | if_unused – If set, the server will only delete the queue if it has no consumers. A channel error will be raised if the queue has consumers. if_empty – If set, the server will only delete the queue if it is empty. If if’s not empty a channel error will be raised. nowait – Do not wait for a reply.

  `get`(no_ack=None)

    Poll the server for a new message.

    Returns the message instance if a message was available, or `None` otherwise.

    Parameters: | no_ack – If set messages received does not have to be acknowledged.

    This method provides direct access to the messages in a queue using a synchronous dialogue, designed for specific types of applications where synchronous functionality is more important than performance.

  `purge`(nowait=False)

    Remove all messages from the queue.

  `queue_bind`(nowait=False)

    Create the queue binding on the server.

    Parameters: | nowait – Do not wait for a reply.

  `queue_declare`(nowait=False, passive=False)

    Declare queue on the server.

    Parameters: | nowait – Do not wait for a reply. passive – If set, the server will not create the queue. The client can use this to check whether a queue exists without modifying the server state.

  `unbind`()

    Delete the binding on the server.

  `when_bound`()

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »